API_SERVER = 'https://lc.compass.io'

company1 = {
    "url": "%s/api/accounts/company/e84cee08-3ffa-11e8-9123-f80f41f8bd97/" % API_SERVER,
    "created": "2018-04-14T11:50:29.757527-04:00",
    "modified": "2018-10-15T13:31:03.704933-04:00",
    "cid": "e84cee08-3ffa-11e8-9123-f80f41f8bd97",
    "is_active": True,
    "name": "Tom Cable",
    "maincomp": False,
    "comments": None,
    "autofix": True,
    "override": True,
    "doubtful": False,
    "confirm_obs": False,
    "confirm_afs": False,
    "policy": "a3a6a312-5fb6-1ce8-bb8b-73192816e4c5",
    "log_server_account": None,
}
